Crate wmo_abbrev_headings

Crate wmo_abbrev_headings 

Data structures for parsing WMO abbreviated headings, in particular data from attachment II-5 of WMO manual 386.

These abbreviated headings are often referenced by their fields TTAAii, and can be seen in NWS bulletings and EMWIN filenames. For example, consider the first two lines of an NWS forecast:

FPUS51 KBOX 211708
ZFPBOX

The FPUS51 part is the WMO abbreviated heading and can be decoded using tables A through D of WMO manual 386. In this particular example, the F indicates a Forecast, the P indicates a public forecast, the US part indicates “United States”, and the 51 part is an NWS specific code that indicates it was issues from the Northeast US.

The NNN part is generally a product category, and for NWS products you can use the the nws-product-list crate to look up what ZFP means.

References:

This crate uses data published by the World Meteorological Organization, but is otherwise unaffiliated with the WMO, and is not an offical WMO library.

Enums

Area
AreaDesignator
GeographicalAreaDesignator
ReportAreaDesignator
WMO.385 table C2
ReportNature
TimeDesignator
WMODataTypeT1
T1 datatype designator
WMODataTypeT2
WMODataTypeT2

Functions

parse_wmo_abbreviated_heading
Parse an abbreviated heading into its two primary data types and area information